@@ -18,11 +18,12 @@ __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
-    'RESTRICT_PLUGIN_ACCESS', 'PLUGINS_MODULE_NAME', 'ACTIVE_LAYOUT', 'LAYOUTS_MODULE_NAME',
-    'DEFAULT_WORKSPACE_NAME', 'DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME',
-    'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'LAYOUT_CELL_UNITS', 'DISPLAY_AUTH_LINK',
+    'RESTRICT_PLUGIN_ACCESS', 'PLUGINS_MODULE_NAME', 'ACTIVE_LAYOUT',
+    'LAYOUTS_MODULE_NAME', 'DEFAULT_WORKSPACE_NAME',
+    'DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME', 'DISPLAY_AUTH_LINK',
+    'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'LAYOUT_CELL_UNITS', 
     'DISPLAY_LOGOUT_LINK', 'WAIT_BETWEEN_TEST_STEPS', 'WAIT_AT_TEST_END',
-    'DEBUG'
+    'PLUGIN_CLIPBOARD_KEY', 'DEBUG'
 )
 
 from dash.conf import get_setting
@@ -49,4 +50,6 @@ DISPLAY_LOGOUT_LINK = DISPLAY_AUTH_LINK
 WAIT_BETWEEN_TEST_STEPS = get_setting('WAIT_BETWEEN_TEST_STEPS')
 WAIT_AT_TEST_END = get_setting('WAIT_AT_TEST_END')
 
+PLUGIN_CLIPBOARD_KEY = get_setting('PLUGIN_CLIPBOARD_KEY')
+
 DEBUG = get_setting('DEBUG')
